from . import _api

if _api.USED_API == _api.QT_API_PYQT5:
    from PyQt5.uic import *
elif _api.USED_API == _api.QT_API_PYQT4:
    from PyQt4.uic import *
elif _api.USED_API == _api.QT_API_PYSIDE:
    # This will fail with an ImportError (as it should)
    from PySide.uic import *
elif _api.USED_API == _api.QT_API_PYSIDE2:
    # This will fail with an ImportError (as it should)
    from PySide2.uic import *



from . import _api

if _api.USED_API == _api.QT_API_PYQT5:
    from PyQt5.QtDBus import *
elif _api.USED_API == _api.QT_API_PYQT4:
    from PyQt4.QtDBus import *
elif _api.USED_API == _api.QT_API_PYSIDE:
    from PySide.QtDBus import *



from . import _api

if _api.USED_API == _api.QT_API_PYQT5:
    from PyQt5.QtXml import *
elif _api.USED_API == _api.QT_API_PYQT4:
    from PyQt4.QtXml import *
elif _api.USED_API == _api.QT_API_PYSIDE:
    from PySide.QtXml import *
elif _api.USED_API == _api.QT_API_PYSIDE2:
    from PySide2.QtXml import *



from . import _api

__all__ = ["QX11Info"]

if _api.USED_API == _api.QT_API_PYQT5:
    from PyQt5.QtX11Extras import *
elif _api.USED_API == _api.QT_API_PYQT4:
    from PyQt4.QtGui import QX11Info
elif _api.USED_API == _api.QT_API_PYSIDE:
    from PySide.QtGui import QX11Info
elif _api.USED_API == _api.QT_API_PYSIDE2:
    from PySide2.QtX11Extras import *
